@@ -20,7 +20,7 @@ import functools
 import getpass
 import sys
 import argparse
-
+import warnings
 
 try:
     import configparser
@@ -32,6 +32,8 @@ try:
 except ImportError:
     from urllib.parse import urlparse, urlunparse
 
+import twine.exceptions
+
 # Shim for raw_input in python3
 if sys.version_info > (3,):
     input_func = input
@@ -63,11 +65,17 @@ def get_config(path="~/.pypirc"):
     parser.read(path)
 
     # Get a list of repositories from the config file
+    # format: https://docs.python.org/3/distutils/packageindex.html#pypirc
     if (parser.has_section("distutils") and
             parser.has_option("distutils", "index-servers")):
         repositories = parser.get("distutils", "index-servers").split()
+    elif parser.has_section("pypi"):
+        # Special case: if the .pypirc file has a 'pypi' section,
+        # even if there's no list of index servers,
+        # be lenient and include that in our list of repositories.
+        repositories = ['pypi']
     else:
-        repositories = ["pypi"]
+        repositories = []
 
     config = {}
 
@@ -103,21 +111,25 @@ def get_config(path="~/.pypirc"):
 
 
 def get_repository_from_config(config_file, repository, repository_url=None):
-    # Get our config from the .pypirc file
+    # Get our config from, if provided, command-line values for the
+    # repository name and URL, or the .pypirc file
     if repository_url and "://" in repository_url:
-        # assume that the repository is actually an URL and just sent
-        # them a dummy with the repo set
+        # prefer CLI `repository_url` over `repository` or .pypirc
         return {
             "repository": repository_url,
             "username": None,
             "password": None,
         }
+    if repository_url and "://" not in repository_url:
+        raise twine.exceptions.UnreachableRepositoryURLDetected(
+            "Repository URL {0} has no protocol. Please add "
+            "'https://'. \n".format(repository_url))
     try:
         return get_config(config_file)[repository]
     except KeyError:
         msg = (
             "Missing '{repo}' section from the configuration file\n"
-            "or not a complete URL in --repository.\n"
+            "or not a complete URL in --repository-url.\n"
             "Maybe you have a out-dated '{cfg}' format?\n"
             "more info: "
             "https://docs.python.org/distutils/packageindex.html#pypirc\n"
@@ -140,14 +152,21 @@ def normalize_repository_url(url):
 
 
 def check_status_code(response):
-    if (response.status_code == 500 and
+    """
+    Shouldn't happen, thanks to the UploadToDeprecatedPyPIDetected
+    exception, but this is in case that breaks and it does.
+    """
+    if (response.status_code == 410 and
             response.url.startswith(("https://pypi.python.org",
                                      "https://testpypi.python.org"))):
-        print("It appears you're uploading to pypi.python.org (or testpypi) "
-              "you've received a 500 error response. PyPI is being phased "
-              "out for pypi.org. Try using https://upload.pypi.org/legacy/ "
+        print("It appears you're uploading to pypi.python.org (or "
+              "testpypi.python.org). You've received a 410 error response. "
+              "Uploading to those sites is deprecated. The new sites are "
+              "pypi.org and test.pypi.org. Try using "
+              "https://upload.pypi.org/legacy/ "
               "(or https://test.pypi.org/legacy/) to upload your packages "
-              "instead. These are the default URLs for Twine now.")
+              "instead. These are the default URLs for Twine now. More at "
+              "https://packaging.python.org/guides/migrating-to-pypi-org/ ")
     response.raise_for_status()
 
 
@@ -196,7 +215,10 @@ def get_password_from_keyring(system, username):
     except ImportError:
         return
 
-    return keyring.get_password(system, username)
+    try:
+        return keyring.get_password(system, username)
+    except Exception as exc:
+        warnings.warn(str(exc))
 
 
 def password_from_keyring_or_prompt(system, username):
